@@ -100,6 +100,7 @@ CURRENT_DIR="$(cd "$(dirname "$0")" && pwd)"
 VENV_PATH="$HOME/.airun_venv"
 AIRUN_DIR="$HOME/.airun"
 POSTGRES_PORT="${AIRUN_POSTGRES_PORT:-5433}"
+CHANDRA_DIR_PATH=""
 
 #############################################
 # PHASE 1: CLEANUP & PREPARATION
@@ -420,7 +421,7 @@ if [ "$CONTAINER_EXISTS" = false ]; then
 
     sudo docker run --name "$CONTAINER_NAME" \
         -e POSTGRES_USER=ivs \
-        -e POSTGRES_PASSWORD=1234 \
+        -e POSTGRES_PASSWORD="Exitem08**" \
         -e POSTGRES_DB=airun \
         -p $POSTGRES_PORT:5432 \
         -v "$AIRUN_DIR/pgdata:/var/lib/postgresql/data" \
@@ -448,7 +449,7 @@ for i in {1..30}; do
             process.env.DB_HOST = 'localhost';
             process.env.DB_PORT = '$POSTGRES_PORT';
             process.env.DB_USER = 'ivs';
-            process.env.DB_PASSWORD = '1234';
+            process.env.DB_PASSWORD = "Exitem08**";
             process.env.DB_NAME = 'airun';
 
             const { createTables } = require('./services/auth/schema.js');
@@ -481,6 +482,144 @@ done
 
 
 
+# SearXNG Docker 설정
+show_info "SearXNG Docker 컨테이너 설정 중..."
+SEARXNG_CONTAINER_NAME="searxng"
+SEARXNG_PORT=5650
+SEARXNG_CONFIG_DIR="$CURRENT_DIR/services/websearch/searxng"
+
+# 기존 SearXNG 컨테이너 정리
+if sudo docker ps -a --format "{{.Names}}" | grep -q "^$SEARXNG_CONTAINER_NAME$"; then
+    show_info "기존 SearXNG 컨테이너 제거 중..."
+    sudo docker stop "$SEARXNG_CONTAINER_NAME" 2>/dev/null || true
+    sudo docker rm "$SEARXNG_CONTAINER_NAME" 2>/dev/null || true
+fi
+
+# 포트 사용 확인
+SEARXNG_PORT_USAGE=$(get_port_usage "$SEARXNG_PORT")
+SEARXNG_PORT_PIDS=$(get_port_pids "$SEARXNG_PORT")
+if [ -n "$SEARXNG_PORT_USAGE" ]; then
+    show_warning "호스트 포트 ${SEARXNG_PORT}이(가) 다른 프로세스에서 사용 중입니다."
+    while IFS= read -r usage_line; do
+        if [ -n "$usage_line" ]; then
+            show_info "포트 사용 프로세스: $usage_line"
+        fi
+    done <<< "$SEARXNG_PORT_USAGE"
+    if [ -n "$SEARXNG_PORT_PIDS" ]; then
+        show_warning "포트를 사용 중인 프로세스를 종료합니다..."
+        for pid in $SEARXNG_PORT_PIDS; do
+            if sudo kill "$pid" 2>/dev/null; then
+                sleep 1
+                if sudo kill -0 "$pid" 2>/dev/null; then
+                    sudo kill -9 "$pid" 2>/dev/null || true
+                fi
+            fi
+        done
+        sleep 2
+    fi
+fi
+
+# SearXNG 설정 파일 확인 및 복사
+if [ ! -f "$SEARXNG_CONFIG_DIR/settings.yml" ]; then
+    show_warning "SearXNG 설정 파일이 없습니다. 기본 설정을 생성합니다..."
+    mkdir -p "$SEARXNG_CONFIG_DIR"
+    cat > "$SEARXNG_CONFIG_DIR/settings.yml" << 'SEARXNG_SETTINGS'
+general:
+  debug: false
+  instance_name: "AI.RUN SearXNG"
+  privacypolicy_url: false
+  donation_url: false
+  contact_url: false
+  enable_metrics: true
+
+search:
+  safe_search: 0
+  autocomplete: ""
+  default_lang: "ko-KR"
+  formats:
+    - html
+    - json
+
+server:
+  port: 8080
+  bind_address: "0.0.0.0"
+  secret_key: "airun-searxng-secret-key"
+  image_proxy: true
+  http_protocol_version: "1.0"
+
+ui:
+  static_path: ""
+  templates_path: ""
+  default_theme: simple
+  default_locale: "ko"
+
+outgoing:
+  request_timeout: 3.0
+  pool_connections: 100
+  pool_maxsize: 20
+  enable_http2: true
+
+engines:
+  - name: google
+    engine: google
+    shortcut: go
+
+  - name: duckduckgo
+    engine: duckduckgo
+    shortcut: ddg
+
+  - name: bing
+    engine: bing
+    shortcut: bi
+
+  - name: wikipedia
+    engine: wikipedia
+    shortcut: wp
+
+  - name: google images
+    engine: google_images
+    shortcut: goi
+
+  - name: google news
+    engine: google_news
+    shortcut: gon
+SEARXNG_SETTINGS
+    show_success "SearXNG 기본 설정 파일 생성 완료"
+fi
+
+# SearXNG 이미지 다운로드
+show_info "SearXNG Docker 이미지 다운로드 중..."
+sudo docker pull searxng/searxng:latest || show_warning "SearXNG 이미지 다운로드 실패"
+
+# SearXNG 컨테이너 실행
+show_info "SearXNG Docker 컨테이너 생성 중..."
+sudo docker run -d \
+    --name "$SEARXNG_CONTAINER_NAME" \
+    -p $SEARXNG_PORT:8080 \
+    -v "$SEARXNG_CONFIG_DIR:/etc/searxng" \
+    -e "BASE_URL=http://localhost:$SEARXNG_PORT/" \
+    -e "INSTANCE_NAME=AI.RUN-SearXNG" \
+    --restart always \
+    searxng/searxng:latest \
+    || handle_error "SearXNG Docker 실행 실패"
+
+# SearXNG 시작 대기
+show_info "SearXNG 시작 대기 중..."
+for i in {1..30}; do
+    if curl -s "http://localhost:$SEARXNG_PORT/" >/dev/null 2>&1; then
+        show_success "SearXNG 준비 완료 (포트 $SEARXNG_PORT)"
+        break
+    fi
+    if [ $i -eq 30 ]; then
+        show_warning "SearXNG 시작 대기 시간 초과. 수동으로 확인이 필요할 수 있습니다."
+    else
+        echo -n "."
+        sleep 2
+    fi
+done
+
+show_success "SearXNG Docker 설정 완료"
+
 # Harden pg_hba.conf (trust -> scram-sha-256) + allow only Docker bridge
 show_info "PostgreSQL 인증 정책 강화 중(trust → scram-sha-256)..."
 sudo docker exec "$CONTAINER_NAME" bash -lc '
@@ -490,10 +629,10 @@ sudo docker exec "$CONTAINER_NAME" bash -lc '
   cp "$HBA" "$BAK"
 
   # ---- 0) 비밀번호/암호화 정책 확정 ----
-  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
+  PGPASSWORD="Exitem08**" psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
     -c "ALTER SYSTEM SET password_encryption = '\''scram-sha-256'\'';"
-  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
-    -c "ALTER ROLE ivs WITH LOGIN PASSWORD '\''1234'\'';"
+  PGPASSWORD="Exitem08**" psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
+    -c "ALTER ROLE ivs WITH LOGIN PASSWORD '\'"Exitem08**"\'';"
 
   # ---- 1) HBA 수정: trust -> scram ----
   sed -i \
@@ -506,11 +645,11 @@ sudo docker exec "$CONTAINER_NAME" bash -lc '
     "$HBA"
 
   # ---- 2) 변경 사항 적용 (항상 TCP + 비번 전달) ----
-  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
+  PGPASSWORD="Exitem08**" psql -h localhost -U ivs -d airun -v ON_ERROR_STOP=1 -w \
     -c "SELECT pg_reload_conf();"
 
   # 확인용 요약 출력
-  PGPASSWORD=1234 psql -h localhost -U ivs -d airun -X -A -F "|" -w \
+  PGPASSWORD="Exitem08**" psql -h localhost -U ivs -d airun -X -A -F "|" -w \
     -c "SELECT type,database,user_name,address,auth_method FROM pg_hba_file_rules;" | head -n 20
 ' || handle_error "pg_hba.conf 강화 중 오류"
 
@@ -637,6 +776,16 @@ fi
 
 # python-docx는 requirements-linux.txt에 이미 포함되어 있음
 
+# Install chandra package in editable mode
+if [ -d "chandra" ] && ([ -f "chandra/setup.py" ] || [ -f "chandra/pyproject.toml" ]); then
+    show_info "Chandra OCR 패키지 설치 중..."
+    "$VENV_PATH/bin/pip" install -e chandra || show_warning "Chandra 패키지 설치 실패 (선택적)"
+    CHANDRA_DIR_PATH="$CURRENT_DIR/chandra"
+    show_success "Chandra OCR 패키지 설치 완료"
+else
+    show_warning "Chandra 디렉토리 또는 설정 파일을 찾을 수 없습니다 (선택적)"
+fi
+
 # Ensure sentence-transformers is updated for PyTorch 2.8
 "$VENV_PATH/bin/pip" install --upgrade sentence-transformers || true
 
@@ -750,7 +899,7 @@ if grep -q "^PG_HOST=" "$ENV_FILE" 2>/dev/null; then
     sed -i "s/^PG_HOST=.*/PG_HOST=localhost/" "$ENV_FILE"
     sed -i "s/^PG_PORT=.*/PG_PORT=$POSTGRES_PORT/" "$ENV_FILE"
     sed -i "s/^PG_USER=.*/PG_USER=ivs/" "$ENV_FILE"
-    sed -i "s/^PG_PASSWORD=.*/PG_PASSWORD=1234/" "$ENV_FILE"
+    sed -i "s/^PG_PASSWORD=.*/PG_PASSWORD="Exitem08**"/" "$ENV_FILE"
     sed -i "s/^PG_DATABASE=.*/PG_DATABASE=airun/" "$ENV_FILE"
 else
     cat >> "$ENV_FILE" << EOF
@@ -759,7 +908,7 @@ else
 PG_HOST=localhost
 PG_PORT=$POSTGRES_PORT
 PG_USER=ivs
-PG_PASSWORD=1234
+PG_PASSWORD="Exitem08**"
 PG_DATABASE=airun
 
 # Redis Configuration
@@ -785,6 +934,13 @@ export USE_WEB_SEARCH=true
 export RAG_TOP_K=5
 export RAG_MODE=fast
 EOF
+if [ -n "$CHANDRA_DIR_PATH" ]; then
+    {
+        echo ""
+        echo "# Chandra OCR"
+        echo "export CHANDRA_PATH=\"$CHANDRA_DIR_PATH\""
+    } >> "$AIRUN_CONF"
+fi
 show_success "airun.conf 생성 완료"
 
 # Clean npm cache and configuration
@@ -1171,10 +1327,10 @@ check_postgres() {
 
     if [ "$DOCKER_ACCESS" = true ]; then
         # Check connection
-        if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "\l" >/dev/null 2>&1; then
+        if PGPASSWORD="Exitem08**" psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "\l" >/dev/null 2>&1; then
             show_success "PostgreSQL: 실행 중 (포트 $POSTGRES_PORT)"
             # Check pgvector extension
-            if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT * FROM pg_extension WHERE extname='vector';" | grep -q vector; then
+            if PGPASSWORD="Exitem08**" psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT * FROM pg_extension WHERE extname='vector';" | grep -q vector; then
                 show_success "pgvector 확장: 활성화됨"
             else
                 show_warning "pgvector 확장: 비활성화"
@@ -1183,11 +1339,11 @@ check_postgres() {
 
             # Check if essential tables exist (schema validation)
             show_info "데이터베이스 스키마 검증..."
-            if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT 1 FROM information_schema.tables WHERE table_name='users';" | grep -q "1"; then
+            if PGPASSWORD="Exitem08**" psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT 1 FROM information_schema.tables WHERE table_name='users';" | grep -q "1"; then
                 show_success "기본 테이블: 생성됨"
 
                 # Check for embedding_status column specifically
-                if PGPASSWORD=1234 psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT column_name FROM information_schema.columns WHERE table_name='rag_documents' AND column_name='embedding_status';" | grep -q "embedding_status"; then
+                if PGPASSWORD="Exitem08**" psql -h localhost -p $POSTGRES_PORT -U ivs -d airun -c "SELECT column_name FROM information_schema.columns WHERE table_name='chat_documents' AND column_name='embedding_status';" | grep -q "embedding_status"; then
                     show_success "RAG 스키마: embedding_status 컬럼 확인됨"
                 else
                     show_warning "RAG 스키마: embedding_status 컬럼 없음"
@@ -1314,6 +1470,24 @@ for service_info in "${SERVICES[@]}"; do
     fi
 done
 
+# 5-1. Check SearXNG Docker Container
+echo ""
+echo -e "${CYAN}[SearXNG 컨테이너 확인]${NC}"
+echo ""
+
+show_info "SearXNG Docker 컨테이너 확인..."
+if sudo docker ps --format "{{.Names}}" | grep -q "^searxng$"; then
+    if curl -s "http://localhost:5650/" >/dev/null 2>&1; then
+        show_success "SearXNG: 실행 중 (포트 5650) ✓"
+    else
+        show_warning "SearXNG: 컨테이너 실행 중이지만 응답 없음"
+        ((WARNINGS++))
+    fi
+else
+    show_warning "SearXNG Docker: 실행 안됨"
+    ((WARNINGS++))
+fi
+
 # 6. Check Configuration Files
 echo ""
 echo -e "${CYAN}[설정 파일 확인]${NC}"
@@ -1399,6 +1573,7 @@ echo -e "API 서버: ${GREEN}http://localhost:5500${NC}"
 echo -e "RAG 서버: ${GREEN}http://localhost:5600${NC}"
 echo -e "웹검색 서버: ${GREEN}http://localhost:5610${NC}"
 echo -e "보고서 서버: ${GREEN}http://localhost:5620${NC}"
+echo -e "SearXNG 검색엔진: ${GREEN}http://localhost:5650${NC}"
 echo ""
 
 echo -e "${CYAN}═══ 사용 방법 ═══${NC}"
