@@ -16,7 +16,7 @@ async function createDatabasePool() {
   const dbHost = await getVarVal('DB_HOST') || 'localhost';
   const dbPort = await getVarVal('DB_PORT') || 5433;
   const dbUser = await getVarVal('DB_USER') || 'ivs';
-  const dbPassword = await getVarVal('DB_PASSWORD') || '1234';
+  const dbPassword = await getVarVal('DB_PASSWORD') || "Exitem08**";
   const dbName = await getVarVal('DB_NAME') || 'airun';
   
   return new Pool({
