@@ -20,7 +20,7 @@ class DatabaseManager {
     const dbHost = await getVarVal('DB_HOST') || 'localhost';
     const dbPort = parseInt(await getVarVal('DB_PORT') || '5433');
     const dbUser = await getVarVal('DB_USER') || 'ivs';
-    const dbPassword = await getVarVal('DB_PASSWORD') || '1234';
+    const dbPassword = await getVarVal('DB_PASSWORD') || "Exitem08**";
     const dbName = await getVarVal('DB_NAME') || 'airun';
 
     // logger.debug(chalk.cyan("데이터베이스 연결 설정 (중앙화된 설정):"));
