@@ -158,6 +158,16 @@ class ToolRegistry {
         };
     }
 
+
+    /**
+     * 도구 객체 반환 (핸들러 포함)
+     * @param {string} toolName - 도구 이름
+     * @returns {Object|null} 도구 객체 (handler 포함)
+     */
+    getTool(toolName) {
+        return this.tools.get(toolName) || null;
+    }
+
     /**
      * 카테고리별 도구 목록
      */
