@@ -386,12 +386,6 @@ export default function AdminUsersPage() {
                 <h2 className="text-xl font-semibold text-gray-900 dark:text-white">
                   시스템 프롬프트 편집 - {editSystemPromptUser.username}
                 </h2>
-                {systemPromptProvider && (
-                  <p className="text-sm text-gray-600 dark:text-gray-400 mt-1">
-                    프로바이더: {systemPromptProvider.toUpperCase()}
-                    {isSystemPromptCustom ? ' (사용자 정의)' : ' (기본 템플릿)'}
-                  </p>
-                )}
               </div>
               <button
                 onClick={() => {
@@ -423,7 +417,7 @@ export default function AdminUsersPage() {
                     <textarea
                       value={systemPrompt}
                       onChange={(e) => setSystemPrompt(e.target.value)}
-                      className="w-full h-96 px-4 py-3 text-sm border border-gray-300 dark:border-gray-600 rounded-lg bg-white dark:bg-gray-800 text-gray-900 dark:text-white focus:ring-2 focus:ring-blue-500 focus:border-transparent resize-none font-mono"
+                      className="w-full h-96 px-4 py-3 text-sm border border-gray-300 dark:border-gray-600 rounded-lg bg-[var(--body-bg)] text-gray-900 dark:text-white focus:ring-2 focus:ring-blue-500 focus:border-transparent resize-none font-mono"
                       placeholder="시스템 프롬프트를 입력하세요..."
                     />
                   </div>
