@@ -5,8 +5,12 @@ import os from 'os';
 import { exec } from 'child_process';
 import { promisify } from 'util';
 import { withAnyAuth } from '../middlewares';
+import { getReportServerUrl } from '@/config/serverConfig';
 
 const execAsync = promisify(exec);
+// process.env.REPORT_ANALYZE_TIMEOUT_MS 설정시 env 파일에 명시. 없으면 기본 60000ms (60초)
+const REPORT_ANALYZE_TIMEOUT_MS = parseInt(process.env.REPORT_ANALYZE_TIMEOUT_MS || '60000', 10);
+const REPORT_GENERATE_TIMEOUT_MS = parseInt(process.env.REPORT_GENERATE_TIMEOUT_MS || '90000', 10);
 
 // 문서/리포트 목록 조회
 export async function GET(req: NextRequest) {
@@ -272,7 +276,7 @@ export async function GET(req: NextRequest) {
         }
 
         // 스트리밍 서버에서 실제 진행 중인 작업 조회 요청
-        const STREAMING_SERVER = 'http://127.0.0.1:5620';
+        const STREAMING_SERVER = getReportServerUrl();
         let userActiveJobs: any[] = [];
         
         try {
@@ -1235,7 +1239,7 @@ export async function POST(req: NextRequest) {
           }
 
           // Report Server의 /analyze 엔드포인트 호출
-          const REPORT_SERVER = 'http://127.0.0.1:5620';
+          const REPORT_SERVER = getReportServerUrl();
           
           console.log(`[Clarification] Report Server 연결 시도: ${REPORT_SERVER}/analyze`);
           
@@ -1244,11 +1248,11 @@ export async function POST(req: NextRequest) {
           let timeoutId: NodeJS.Timeout | undefined;
           
           try {
-            // 타임아웃 설정 (30초)
+            // 타임아웃 설정
             const controller = new AbortController();
-            timeoutId = setTimeout(() => controller.abort(), 30000);
+            timeoutId = setTimeout(() => controller.abort(), REPORT_ANALYZE_TIMEOUT_MS);
             
-            console.log(`[Clarification] fetch 요청 시작...`);
+            console.log(`[Clarification] fetch 요청 시작... (${REPORT_ANALYZE_TIMEOUT_MS}ms timeout)`);
             
             response = await fetch(`${REPORT_SERVER}/analyze`, {
               method: 'POST',
@@ -1359,17 +1363,19 @@ export async function POST(req: NextRequest) {
           }
 
           // Report Server의 /generate-enhanced 엔드포인트 호출
-          const REPORT_SERVER = 'http://127.0.0.1:5620';
+          const REPORT_SERVER = getReportServerUrl();
           
           let response: Response;
           let enhancedResult: any;
           let timeoutId: NodeJS.Timeout | undefined;
           
           try {
-            // 타임아웃 설정 (30초)
+            // 타임아웃 설정
             const controller = new AbortController();
-            timeoutId = setTimeout(() => controller.abort(), 30000);
+            timeoutId = setTimeout(() => controller.abort(), REPORT_GENERATE_TIMEOUT_MS);
             
+            console.log(`[Clarification] 향상된 생성 fetch 시작... (${REPORT_GENERATE_TIMEOUT_MS}ms timeout)`);
+
             response = await fetch(`${REPORT_SERVER}/generate-enhanced`, {
               method: 'POST',
               headers,
@@ -1655,4 +1661,4 @@ export async function POST(req: NextRequest) {
       );
     }
   });
-}
\ No newline at end of file
+}
