@@ -2,9 +2,7 @@ import { NextResponse } from 'next/server';
 import os from 'os';
 import fs from 'fs';
 import path from 'path';
-import pg from 'pg';
-
-const { Pool } = pg;
+import { getDatabasePool } from '@/utils/dbConfig';
 
 function getAppDataPath() {
   switch (process.platform) {
@@ -76,34 +74,29 @@ async function getAllLogs() {
 }
 
 async function getPostgreSQLInfo() {
-  const pool = new Pool({
-    user: (await getDatabasePool()).options.user,
-    host: (await getDatabasePool()).options.host,
-    database: (await getDatabasePool()).options.database,
-    password: (await getDatabasePool()).options.password,
-    port: (await getDatabasePool()).options.port,
-    max: 1,
-  });
-
+  const dbPool = await getDatabasePool();
   try {
-    const client = await pool.connect();
-    
-    const connectionQuery = `
+    const result = await dbPool.query<{
+      current_connections: string;
+      max_connections: string;
+    }>(`
       SELECT 
         (SELECT count(*) FROM pg_stat_activity WHERE datname = current_database()) as current_connections,
         (SELECT setting::int FROM pg_settings WHERE name = 'max_connections') as max_connections
-    `;
-    
-    const result = await client.query(connectionQuery);
+    `);
+
+    if (result.rows.length === 0) {
+      return null;
+    }
+
     const { current_connections, max_connections } = result.rows[0];
-    
-    client.release();
-    await pool.end();
-    
+    const current = parseInt(current_connections, 10);
+    const max = parseInt(max_connections, 10);
+
     return {
-      current_connections: parseInt(current_connections),
-      max_connections: parseInt(max_connections),
-      connection_usage_percent: Math.round((current_connections / max_connections) * 100)
+      current_connections: current,
+      max_connections: max,
+      connection_usage_percent: max > 0 ? Math.round((current / max) * 100) : 0
     };
   } catch (error) {
     console.error('PostgreSQL 정보 조회 오류:', error);
@@ -164,4 +157,4 @@ export async function GET() {
   } catch (error) {
     return NextResponse.json({ success: false, error: { message: error instanceof Error ? error.message : String(error) } }, { status: 500 });
   }
-} 
\ No newline at end of file
+} 
