@@ -1,5 +1,5 @@
 import { NextRequest, NextResponse } from 'next/server';
-import * as XLSX from 'xlsx';
+import ExcelJS from 'exceljs';
 
 export async function POST(request: NextRequest) {
   try {
@@ -15,16 +15,31 @@ export async function POST(request: NextRequest) {
 
     // Excel 파일 분석
     const buffer = Buffer.from(await file.arrayBuffer());
-    const workbook = XLSX.read(buffer, { type: 'buffer' });
+    const workbook = new ExcelJS.Workbook();
+    await workbook.xlsx.load(buffer);
+
+    const sheets = workbook.worksheets.map(worksheet => {
+      const jsonData: any[][] = [];
+      worksheet.eachRow((row, rowNumber) => {
+        const rowData: any[] = [];
+        row.eachCell({ includeEmpty: true }, (cell) => {
+          let value = cell.value;
+
+          // richText 객체를 텍스트로 변환
+          if (typeof value === 'object' && value !== null && 'richText' in value) {
+            value = value.richText.map((t: any) => t.text).join('');
+          }
+
+          rowData.push(value ?? '');
+        });
+        jsonData.push(rowData);
+      });
 
-    const sheets = workbook.SheetNames.map(sheetName => {
-      const worksheet = workbook.Sheets[sheetName];
-      const jsonData = XLSX.utils.sheet_to_json(worksheet, { header: 1, defval: '' });
       const headers = jsonData[0] as string[] || [];
       const preview = jsonData.slice(0, 11); // 첫 10행 미리보기
-      
+
       return {
-        name: sheetName,
+        name: worksheet.name,
         headers,
         preview,
         rowCount: jsonData.length,
