@@ -1,5 +1,5 @@
 import { NextRequest, NextResponse } from 'next/server';
-import * as XLSX from 'xlsx';
+import ExcelJS from 'exceljs';
 
 export async function POST(request: NextRequest) {
   try {
@@ -16,7 +16,8 @@ export async function POST(request: NextRequest) {
 
     // Excel 파일 분석
     const buffer = Buffer.from(await file.arrayBuffer());
-    const workbook = XLSX.read(buffer, { type: 'buffer' });
+    const workbook = new ExcelJS.Workbook();
+    await workbook.xlsx.load(buffer);
 
     // AI 추천 로직
     const recommendations = await generateExcelRecommendations(sheetsData, workbook);
@@ -50,7 +51,7 @@ export async function POST(request: NextRequest) {
   }
 }
 
-async function generateExcelRecommendations(sheetsData: any[], workbook: XLSX.WorkBook) {
+async function generateExcelRecommendations(sheetsData: any[], workbook: ExcelJS.Workbook) {
   const recommendations: any = {
     selectedSheet: '',
     columns: [],
