@@ -41,12 +41,12 @@ const JOB_INDEX_KEY = 'background_jobs:index';
 
 
 // 파일 업로드 백그라운드 처리 함수
-async function processFileUploadEventBased(jobId: string, fileData: any, userId: string, userApiKey: string | null) {
+async function processFileUploadEventBased(jobId: string, fileData: any, userId: string, userApiKey: string | null, metadata?: any) {
   // 디버그 로그 파일에 기록
   const fs = require('fs');
   const logFile = '/tmp/bg_job_debug.log';
   fs.appendFileSync(logFile, `
-[${new Date().toISOString()}] processFileUploadEventBased 시작 - jobId: ${jobId}, file: ${fileData.name}
+[${new Date().toISOString()}] processFileUploadEventBased 시작 - jobId: ${jobId}, file: ${fileData.name}, lastModified: ${fileData.lastModified || metadata?.lastModified || 'N/A'}
 `);
   try {
     fs.appendFileSync(logFile, `[${new Date().toISOString()}] try 블록 진입
@@ -104,6 +104,17 @@ async function processFileUploadEventBased(jobId: string, fileData: any, userId:
     formData.append('overwrite', 'true');
     formData.append('force', 'true'); // 강제 덮어쓰기
 
+    // 파일 수정일자 추가
+    const modificationTime = fileData.lastModified || (metadata && metadata.lastModified) || null;
+    if (modificationTime) {
+      formData.append('modification_time', modificationTime);
+      fs.appendFileSync(logFile, `[${new Date().toISOString()}] modification_time 추가: ${modificationTime}
+`);
+    } else {
+      fs.appendFileSync(logFile, `[${new Date().toISOString()}] modification_time 없음
+`);
+    }
+
     // API 서버를 통해 RAG 서버에 업로드
     // serverConfig에서 API 서버 URL 가져오기
     const { getApiServerUrl } = await import('@/config/serverConfig');
@@ -607,15 +618,22 @@ export async function POST(req: NextRequest) {
             userApiKey = req.headers.get('x-api-key');
             console.log(`[백그라운드 작업] API 키 헤더에서 가져옴: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
           } else if (user && user.apiKeys && user.apiKeys.length > 0) {
-            // JWT 토큰 인증인 경우 user 객체에서 API 키 가져오기
-            userApiKey = user.apiKeys[0].key || user.apiKeys[0].key_value;
-            console.log(`[백그라운드 작업] 사용자 객체에서 API 키 가져옴: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
+            // JWT 토큰 인증인 경우 user 객체에서 활성화된 API 키 찾기
+            const activeApiKey = user.apiKeys.find((apiKey: any) => apiKey.status === 'active');
+            if (activeApiKey) {
+              userApiKey = activeApiKey.key || activeApiKey.key_value;
+              console.log(`[백그라운드 작업] 사용자 객체에서 활성 API 키 가져옴: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
+            } else {
+              console.warn(`[백그라운드 작업] 활성화된 API 키가 없습니다. 첫 번째 키 사용`);
+              userApiKey = user.apiKeys[0].key || user.apiKeys[0].key_value;
+              console.log(`[백그라운드 작업] 사용자 객체에서 API 키 가져옴 (비활성): ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
+            }
           }
           
           console.log(`[백그라운드 작업] 사용할 API 키: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
           
           // 백그라운드에서 파일 업로드 처리 시작 (non-blocking)
-          processFileUploadEventBased(jobId, fileData, job.userId, userApiKey)
+          processFileUploadEventBased(jobId, fileData, job.userId, userApiKey, metadata)
             .catch(error => console.error(`[백그라운드 작업 ${jobId}] 처리 실패:`, error));
         } else if (type === 'ticket_sync') {
           console.log(`[백그라운드 작업] 티켓 동기화 작업 - 인증 타입: ${authType}, 사용자:`, user);
@@ -628,9 +646,16 @@ export async function POST(req: NextRequest) {
             userApiKey = req.headers.get('x-api-key');
             console.log(`[백그라운드 작업] API 키 헤더에서 가져옴: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
           } else if (user && user.apiKeys && user.apiKeys.length > 0) {
-            // JWT 토큰 인증인 경우 user 객체에서 API 키 가져오기
-            userApiKey = user.apiKeys[0].key || user.apiKeys[0].key_value;
-            console.log(`[백그라운드 작업] 사용자 객체에서 API 키 가져옴: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
+            // JWT 토큰 인증인 경우 user 객체에서 활성화된 API 키 찾기
+            const activeApiKey = user.apiKeys.find((apiKey: any) => apiKey.status === 'active');
+            if (activeApiKey) {
+              userApiKey = activeApiKey.key || activeApiKey.key_value;
+              console.log(`[백그라운드 작업] 사용자 객체에서 활성 API 키 가져옴: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
+            } else {
+              console.warn(`[백그라운드 작업] 활성화된 API 키가 없습니다. 첫 번째 키 사용`);
+              userApiKey = user.apiKeys[0].key || user.apiKeys[0].key_value;
+              console.log(`[백그라운드 작업] 사용자 객체에서 API 키 가져옴 (비활성): ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
+            }
           }
           
           console.log(`[백그라운드 작업] 사용할 API 키: ${userApiKey ? userApiKey.substring(0, 20) + '...' : 'None'}`);
