@@ -4,6 +4,9 @@ import { useState, useEffect, useRef } from 'react';
 import { Upload, FileText, Image, List, Eye, Plus, Trash2, Edit2, ExternalLink, Copy, Check } from 'lucide-react';
 import { useRouter } from 'next/navigation';
 import * as pdfjsLib from 'pdfjs-dist';
+import ReactMarkdown from 'react-markdown';
+import remarkGfm from 'remark-gfm';
+import { html as beautifyHtml } from 'js-beautify';
 import FormSubmissionModal from '@/components/FormSubmissionModal';
 import ResponsesViewModal from '@/components/ResponsesViewModal';
 
@@ -73,6 +76,11 @@ export default function FormBuilderPage() {
   // 탭 상태
   const [activePreviewTab, setActivePreviewTab] = useState<1 | 2>(1);
   const [activeContentTab, setActiveContentTab] = useState<'html' | 'markdown' | 'json'>('html');
+  const [activeSourceTab, setActiveSourceTab] = useState<'html' | 'markdown' | 'json'>('html');
+
+  // 미리보기 페이지네이션
+  const [currentPreviewPage, setCurrentPreviewPage] = useState(1);
+  const PAGES_PER_VIEW = 5;
 
   // PDF.js 워커 설정
   useEffect(() => {
@@ -216,9 +224,9 @@ export default function FormBuilderPage() {
 
       const images: string[] = [];
 
-      // 최대 5페이지까지만 미리보기
-      const numPages = Math.min(pdf.numPages, 5);
-      console.log(`🖼️ ${numPages}개 페이지를 이미지로 변환 시작 (전체: ${pdf.numPages}페이지)`);
+      // 모든 페이지를 이미지로 변환 (페이지네이션으로 표시)
+      const numPages = pdf.numPages;
+      console.log(`🖼️ ${numPages}개 페이지를 이미지로 변환 시작`);
 
       for (let pageNum = 1; pageNum <= numPages; pageNum++) {
         const page = await pdf.getPage(pageNum);
@@ -469,6 +477,7 @@ export default function FormBuilderPage() {
     setSelectedPages([]);
     setPageSelectionMode('all');
     setPageRangeInput('');
+    setCurrentPreviewPage(1);
   };
 
   const handleDeleteForm = async (formId: string) => {
@@ -782,29 +791,45 @@ export default function FormBuilderPage() {
                     </div>
                   ) : uploadedDocument.type === 'pdf' && pdfPreviewImages.length > 0 ? (
                     <div className="space-y-4">
-                      {pdfPreviewImages.map((img, index) => (
-                        <div key={index}>
-                          <p className="text-xs text-gray-500 dark:text-gray-400 mb-2">페이지 {index + 1}</p>
-                          <img
-                            src={img}
-                            alt={`Page ${index + 1}`}
-                            className="max-w-full h-auto rounded-lg shadow-lg"
-                          />
-                        </div>
-                      ))}
-                      {pdfPreviewImages.length >= 5 && totalPages > 5 && (
-                        <div className="text-center py-4 px-3 bg-blue-50 dark:bg-blue-900/20 rounded-lg border border-blue-200 dark:border-blue-800">
-                          <p className="text-sm text-blue-700 dark:text-blue-300 font-medium">
-                            ... 더 많은 페이지가 있습니다
-                          </p>
-                          <p className="text-xs text-blue-600 dark:text-blue-400 mt-1">
-                            전체 {totalPages}페이지 중 {pdfPreviewImages.length}페이지 미리보기
-                          </p>
-                          <p className="text-xs text-gray-600 dark:text-gray-400 mt-2">
-                            오른쪽에서 처리할 페이지를 선택할 수 있습니다
-                          </p>
+                      {/* 페이지네이션 컨트롤 (상단) */}
+                      {pdfPreviewImages.length > PAGES_PER_VIEW && (
+                        <div className="flex items-center justify-between bg-gray-100 dark:bg-gray-700 p-3 rounded-lg">
+                          <button
+                            onClick={() => setCurrentPreviewPage(Math.max(1, currentPreviewPage - 1))}
+                            disabled={currentPreviewPage === 1}
+                            className="px-3 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-sm"
+                          >
+                            ← 이전
+                          </button>
+                          <span className="text-sm font-medium">
+                            {Math.min((currentPreviewPage - 1) * PAGES_PER_VIEW + 1, pdfPreviewImages.length)} - {Math.min(currentPreviewPage * PAGES_PER_VIEW, pdfPreviewImages.length)} / {pdfPreviewImages.length}
+                          </span>
+                          <button
+                            onClick={() => setCurrentPreviewPage(Math.min(Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW), currentPreviewPage + 1))}
+                            disabled={currentPreviewPage >= Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW)}
+                            className="px-3 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-sm"
+                          >
+                            다음 →
+                          </button>
                         </div>
                       )}
+
+                      {/* 현재 페이지 범위의 이미지 표시 */}
+                      {pdfPreviewImages
+                        .slice((currentPreviewPage - 1) * PAGES_PER_VIEW, currentPreviewPage * PAGES_PER_VIEW)
+                        .map((img, relativeIndex) => {
+                          const absoluteIndex = (currentPreviewPage - 1) * PAGES_PER_VIEW + relativeIndex;
+                          return (
+                            <div key={absoluteIndex}>
+                              <p className="text-xs text-gray-500 dark:text-gray-400 mb-2">페이지 {absoluteIndex + 1}</p>
+                              <img
+                                src={img}
+                                alt={`Page ${absoluteIndex + 1}`}
+                                className="max-w-full h-auto rounded-lg shadow-lg"
+                              />
+                            </div>
+                          );
+                        })}
                     </div>
                   ) : uploadedDocument.type === 'pdf' ? (
                     <div className="flex flex-col items-center justify-center h-full">
@@ -944,12 +969,40 @@ export default function FormBuilderPage() {
                     />
                   ) : uploadedDocument.type === 'pdf' && pdfPreviewImages.length > 0 ? (
                     <div className="space-y-4">
-                      {pdfPreviewImages.map((img, index) => (
-                        <div key={index}>
-                          <p className="text-xs text-gray-500 dark:text-gray-400 mb-2">페이지 {index + 1}</p>
-                          <img src={img} alt={`Page ${index + 1}`} className="max-w-full h-auto rounded-lg shadow-lg" />
+                      {/* 페이지네이션 컨트롤 */}
+                      {pdfPreviewImages.length > PAGES_PER_VIEW && (
+                        <div className="flex items-center justify-between bg-gray-100 dark:bg-gray-700 p-3 rounded-lg">
+                          <button
+                            onClick={() => setCurrentPreviewPage(Math.max(1, currentPreviewPage - 1))}
+                            disabled={currentPreviewPage === 1}
+                            className="px-3 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-sm"
+                          >
+                            ← 이전
+                          </button>
+                          <span className="text-sm font-medium">
+                            {Math.min((currentPreviewPage - 1) * PAGES_PER_VIEW + 1, pdfPreviewImages.length)} - {Math.min(currentPreviewPage * PAGES_PER_VIEW, pdfPreviewImages.length)} / {pdfPreviewImages.length}
+                          </span>
+                          <button
+                            onClick={() => setCurrentPreviewPage(Math.min(Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW), currentPreviewPage + 1))}
+                            disabled={currentPreviewPage >= Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW)}
+                            className="px-3 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-sm"
+                          >
+                            다음 →
+                          </button>
                         </div>
-                      ))}
+                      )}
+
+                      {pdfPreviewImages
+                        .slice((currentPreviewPage - 1) * PAGES_PER_VIEW, currentPreviewPage * PAGES_PER_VIEW)
+                        .map((img, relativeIndex) => {
+                          const absoluteIndex = (currentPreviewPage - 1) * PAGES_PER_VIEW + relativeIndex;
+                          return (
+                            <div key={absoluteIndex}>
+                              <p className="text-xs text-gray-500 dark:text-gray-400 mb-2">페이지 {absoluteIndex + 1}</p>
+                              <img src={img} alt={`Page ${absoluteIndex + 1}`} className="max-w-full h-auto rounded-lg shadow-lg" />
+                            </div>
+                          );
+                        })}
                     </div>
                   ) : (
                     <div className="flex items-center justify-center h-full">
@@ -1030,7 +1083,7 @@ export default function FormBuilderPage() {
                     : 'text-gray-500 hover:text-gray-700 dark:text-gray-400 dark:hover:text-gray-200'
                 }`}
               >
-                HTML 소스
+                소스
               </button>
             </div>
 
@@ -1053,12 +1106,40 @@ export default function FormBuilderPage() {
                       />
                     ) : uploadedDocument.type === 'pdf' && pdfPreviewImages.length > 0 ? (
                       <div className="space-y-4">
-                        {pdfPreviewImages.map((img, index) => (
-                          <div key={index}>
-                            <p className="text-xs text-gray-500 dark:text-gray-400 mb-2">페이지 {index + 1}</p>
-                            <img src={img} alt={`Page ${index + 1}`} className="max-w-full h-auto rounded-lg shadow-lg" />
+                        {/* 페이지네이션 컨트롤 */}
+                        {pdfPreviewImages.length > PAGES_PER_VIEW && (
+                          <div className="flex items-center justify-between bg-gray-100 dark:bg-gray-700 p-3 rounded-lg">
+                            <button
+                              onClick={() => setCurrentPreviewPage(Math.max(1, currentPreviewPage - 1))}
+                              disabled={currentPreviewPage === 1}
+                              className="px-3 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-sm"
+                            >
+                              ← 이전
+                            </button>
+                            <span className="text-sm font-medium">
+                              {Math.min((currentPreviewPage - 1) * PAGES_PER_VIEW + 1, pdfPreviewImages.length)} - {Math.min(currentPreviewPage * PAGES_PER_VIEW, pdfPreviewImages.length)} / {pdfPreviewImages.length}
+                            </span>
+                            <button
+                              onClick={() => setCurrentPreviewPage(Math.min(Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW), currentPreviewPage + 1))}
+                              disabled={currentPreviewPage >= Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW)}
+                              className="px-3 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-sm"
+                            >
+                              다음 →
+                            </button>
                           </div>
-                        ))}
+                        )}
+
+                        {pdfPreviewImages
+                          .slice((currentPreviewPage - 1) * PAGES_PER_VIEW, currentPreviewPage * PAGES_PER_VIEW)
+                          .map((img, relativeIndex) => {
+                            const absoluteIndex = (currentPreviewPage - 1) * PAGES_PER_VIEW + relativeIndex;
+                            return (
+                              <div key={absoluteIndex}>
+                                <p className="text-xs text-gray-500 dark:text-gray-400 mb-2">페이지 {absoluteIndex + 1}</p>
+                                <img src={img} alt={`Page ${absoluteIndex + 1}`} className="max-w-full h-auto rounded-lg shadow-lg" />
+                              </div>
+                            );
+                          })}
                       </div>
                     ) : (
                       <div className="flex items-center justify-center h-full">
@@ -1120,8 +1201,10 @@ export default function FormBuilderPage() {
                     )}
                     {activeContentTab === 'markdown' && (
                       analyzedMarkdown ? (
-                        <div className="prose dark:prose-invert max-w-none whitespace-pre-wrap">
-                          {analyzedMarkdown}
+                        <div className="prose dark:prose-invert max-w-none markdown-preview-content">
+                          <ReactMarkdown remarkPlugins={[remarkGfm]}>
+                            {analyzedMarkdown}
+                          </ReactMarkdown>
                         </div>
                       ) : (
                         <p className="text-gray-500 dark:text-gray-400">Markdown 결과가 없습니다</p>
@@ -1141,17 +1224,61 @@ export default function FormBuilderPage() {
               </div>
               )}
 
-              {/* Tab 2: HTML 소스 + 폼 미리보기 */}
+              {/* Tab 2: 소스 (HTML/Markdown) + 폼 미리보기 */}
               {activePreviewTab === 2 && (
               <div className="h-full flex gap-4">
-                {/* 왼쪽: HTML 소스 코드 */}
+                {/* 왼쪽: 소스 코드 (HTML/Markdown 선택 가능) */}
                 <div className="w-1/2 bg-white dark:bg-gray-800 rounded-lg border border-gray-200 dark:border-gray-700 overflow-hidden">
                   <div className="bg-gray-100 dark:bg-gray-700 px-4 py-2 border-b border-gray-200 dark:border-gray-600">
-                    <h3 className="font-semibold">HTML 소스</h3>
+                    <div className="flex items-center justify-between">
+                      <h3 className="font-semibold">소스</h3>
+                      <div className="flex gap-2">
+                        <button
+                          onClick={() => setActiveSourceTab('html')}
+                          className={`px-3 py-1 text-sm rounded ${
+                            activeSourceTab === 'html'
+                              ? 'bg-blue-600 text-white'
+                              : 'bg-gray-200 dark:bg-gray-600 text-gray-700 dark:text-gray-300'
+                          }`}
+                        >
+                          HTML
+                        </button>
+                        <button
+                          onClick={() => setActiveSourceTab('markdown')}
+                          className={`px-3 py-1 text-sm rounded ${
+                            activeSourceTab === 'markdown'
+                              ? 'bg-blue-600 text-white'
+                              : 'bg-gray-200 dark:bg-gray-600 text-gray-700 dark:text-gray-300'
+                          }`}
+                        >
+                          Markdown
+                        </button>
+                        <button
+                          onClick={() => setActiveSourceTab('json')}
+                          className={`px-3 py-1 text-sm rounded ${
+                            activeSourceTab === 'json'
+                              ? 'bg-blue-600 text-white'
+                              : 'bg-gray-200 dark:bg-gray-600 text-gray-700 dark:text-gray-300'
+                          }`}
+                        >
+                          JSON
+                        </button>
+                      </div>
+                    </div>
                   </div>
                   <div className="h-[calc(100%-3rem)] overflow-y-auto p-4">
-                    <pre className="text-xs bg-gray-50 dark:bg-gray-900 p-4 rounded-lg overflow-x-auto">
-                      <code>{analyzedHtml || analyzedMarkdown || '소스 없음'}</code>
+                    <pre className="text-xs bg-gray-50 dark:bg-gray-900 p-4 rounded-lg overflow-x-auto" style={{ whiteSpace: 'pre' }}>
+                      <code>
+                        {activeSourceTab === 'html' && (analyzedHtml ? beautifyHtml(analyzedHtml, {
+                          indent_size: 2,
+                          indent_char: ' ',
+                          wrap_line_length: 0,
+                          preserve_newlines: true,
+                          max_preserve_newlines: 2
+                        }) : '소스 없음')}
+                        {activeSourceTab === 'markdown' && (analyzedMarkdown || '소스 없음')}
+                        {activeSourceTab === 'json' && (analyzedStructuredJson ? JSON.stringify(analyzedStructuredJson, null, 2) : '소스 없음')}
+                      </code>
                     </pre>
                   </div>
                 </div>
@@ -1209,12 +1336,40 @@ export default function FormBuilderPage() {
                       />
                     ) : uploadedDocument.type === 'pdf' && pdfPreviewImages.length > 0 ? (
                       <div className="space-y-4">
-                        {pdfPreviewImages.map((img, index) => (
-                          <div key={index}>
-                            <p className="text-xs text-gray-500 dark:text-gray-400 mb-1">페이지 {index + 1}</p>
-                            <img src={img} alt={`Page ${index + 1}`} className="max-w-full h-auto rounded-lg shadow-sm" />
+                        {/* 페이지네이션 컨트롤 */}
+                        {pdfPreviewImages.length > PAGES_PER_VIEW && (
+                          <div className="flex items-center justify-between bg-gray-100 dark:bg-gray-700 p-2 rounded-lg">
+                            <button
+                              onClick={() => setCurrentPreviewPage(Math.max(1, currentPreviewPage - 1))}
+                              disabled={currentPreviewPage === 1}
+                              className="px-2 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-xs"
+                            >
+                              ← 이전
+                            </button>
+                            <span className="text-xs font-medium">
+                              {Math.min((currentPreviewPage - 1) * PAGES_PER_VIEW + 1, pdfPreviewImages.length)} - {Math.min(currentPreviewPage * PAGES_PER_VIEW, pdfPreviewImages.length)} / {pdfPreviewImages.length}
+                            </span>
+                            <button
+                              onClick={() => setCurrentPreviewPage(Math.min(Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW), currentPreviewPage + 1))}
+                              disabled={currentPreviewPage >= Math.ceil(pdfPreviewImages.length / PAGES_PER_VIEW)}
+                              className="px-2 py-1 bg-blue-600 text-white rounded hover:bg-blue-700 disabled:opacity-50 disabled:cursor-not-allowed text-xs"
+                            >
+                              다음 →
+                            </button>
                           </div>
-                        ))}
+                        )}
+
+                        {pdfPreviewImages
+                          .slice((currentPreviewPage - 1) * PAGES_PER_VIEW, currentPreviewPage * PAGES_PER_VIEW)
+                          .map((img, relativeIndex) => {
+                            const absoluteIndex = (currentPreviewPage - 1) * PAGES_PER_VIEW + relativeIndex;
+                            return (
+                              <div key={absoluteIndex}>
+                                <p className="text-xs text-gray-500 dark:text-gray-400 mb-1">페이지 {absoluteIndex + 1}</p>
+                                <img src={img} alt={`Page ${absoluteIndex + 1}`} className="max-w-full h-auto rounded-lg shadow-sm" />
+                              </div>
+                            );
+                          })}
                       </div>
                     ) : (
                       <div className="flex items-center justify-center h-full">
