@@ -15,8 +15,8 @@ initSupportTicketsTable();
 const inter = Inter({ subsets: ['latin'] });
 
 export const metadata: Metadata = {
-  title: 'AI 워크스페이스',
-  description: 'AI 기반 통합 워크스페이스',
+  title: 'Build Your Sovereign AI',
+  description: 'Build Your Sovereign AI - Private & Secure',
 };
 
 export default function RootLayout({
