@@ -1,8 +1,12 @@
 'use client'
 
 import Link from 'next/link'
-import { useEffect, useState } from 'react'
-import { useRouter } from 'next/navigation'
+
+import { useEffect, useState, Suspense } from 'react'
+import { useRouter, useSearchParams } from 'next/navigation'
+import { Metadata } from 'next'
+
+
 
 interface User {
   id: string
@@ -85,10 +89,19 @@ const advantages = [
   }
 ]
 
-export default function HomePage() {
+function HomePageContent() {
   const router = useRouter()
+  const searchParams = useSearchParams()
   const [user, setUser] = useState<User | null>(null)
   const [isLoading, setIsLoading] = useState(false)
+  
+  // URL에서 슬로건 파라미터 가져오기
+  const slogan = searchParams?.get('slogan') || 'Build Your Sovereign AI - Private & Secure'
+
+  // 페이지 타이틀에 슬로건 설정
+  useEffect(() => {
+    document.title = slogan
+  }, [slogan])
 
   useEffect(() => {
     // 로컬 스토리지에서 사용자 정보 확인
@@ -166,6 +179,10 @@ export default function HomePage() {
 
   return (
     <div className="min-h-screen" style={{ backgroundColor: 'var(--background)' }}>
+      {/* URL Slogan Banner */}
+      <div className="w-full py-3 px-4 text-center" style={{ backgroundColor: '#1e40af' }}>
+        <span className="text-white font-semibold text-lg">{slogan}</span>
+      </div>
       {/* Hero Section */}
       <div className="relative overflow-hidden py-20 px-4">
         <div className="absolute inset-0 bg-gradient-to-br from-blue-50 via-indigo-50 to-purple-50 dark:from-gray-900 dark:via-blue-950 dark:to-indigo-950"></div>
@@ -462,4 +479,12 @@ export default function HomePage() {
 
     </div>
   )
-}
\ No newline at end of file
+}
+
+export default function HomePage() {
+  return (
+    <Suspense fallback={<div>Loading...</div>}>
+      <HomePageContent />
+    </Suspense>
+  )
+}
