@@ -95,7 +95,12 @@ export default function ProfilePage() {
   // 모달 상태
   const [showConfirmModal, setShowConfirmModal] = useState(false);
   const [showDeleteAllConfirmModal, setShowDeleteAllConfirmModal] = useState(false);
-  const [memoryToDelete, setMemoryToDelete] = useState<number | null>(null);
+  const [memoryToDelete, setMemoryToDelete] = useState<ContextMemory | null>(null);
+
+  // API 키 삭제 모달 상태
+  const [showApiKeyDeleteModal, setShowApiKeyDeleteModal] = useState(false);
+  const [apiKeyToDelete, setApiKeyToDelete] = useState<{ id: number; name: string } | null>(null);
+  const [deletingApiKey, setDeletingApiKey] = useState(false);
   
   const router = useRouter();
 
@@ -366,8 +371,8 @@ export default function ProfilePage() {
   };
 
   // 개별 메모리 삭제 확인
-  const handleDeleteMemory = (memoryId: number) => {
-    setMemoryToDelete(memoryId);
+  const handleDeleteMemory = (memory: ContextMemory) => {
+    setMemoryToDelete(memory);
     setShowConfirmModal(true);
   };
 
@@ -381,11 +386,8 @@ export default function ProfilePage() {
     if (!memoryToDelete) return;
 
     try {
-      // 개별 메모리는 실제로 삭제하지 않고 참조 횟수 관리
-      const memory = contextMemories.find(m => (m.id || 0) === memoryToDelete);
-      if (!memory) return;
-
-      const res = await externalApiClient.delete(`/context/memories/${memory.type}/${encodeURIComponent(memory.content)}`);
+      // 메모리 타입과 내용으로 삭제 요청
+      const res = await externalApiClient.delete(`/context/memories/${memoryToDelete.type}/${encodeURIComponent(memoryToDelete.content)}`);
       if (res.success) {
         await fetchContextData();
         setSuccess('메모리가 삭제되었습니다.');
@@ -405,12 +407,17 @@ export default function ProfilePage() {
   // 단기 메모리 초기화 실행
   const confirmDeleteAllMemories = async () => {
     try {
+      console.log('단기 메모리 초기화 API 호출...');
       const res = await externalApiClient.delete('/context/memories/short-term');
+      console.log('API 응답:', res);
       if (res.success) {
+        console.log('단기 메모리 초기화 성공, 데이터 다시 불러오는 중...');
         await fetchContextData();
+        console.log('데이터 새로고침 완료');
         setSuccess('단기 메모리가 초기화되었습니다.');
         setTimeout(() => setSuccess(null), 3000);
       } else {
+        console.error('단기 메모리 초기화 실패:', res.error);
         setError('단기 메모리 초기화에 실패했습니다.');
       }
     } catch (error) {
@@ -438,6 +445,49 @@ export default function ProfilePage() {
     }
   };
 
+  // API 키 삭제 확인 모달 열기
+  const handleDeleteApiKey = (apiKey: ApiKey) => {
+    setApiKeyToDelete({ id: apiKey.id, name: apiKey.name });
+    setShowApiKeyDeleteModal(true);
+  };
+
+  // API 키 삭제 실행
+  const confirmDeleteApiKey = async () => {
+    if (!apiKeyToDelete) return;
+
+    setDeletingApiKey(true);
+    setError(null);
+
+    try {
+      const response = await fetch(`/api/profile/api-keys/${apiKeyToDelete.id}`, {
+        method: 'DELETE',
+        credentials: 'include'
+      });
+
+      const data = await response.json();
+
+      if (response.ok && data.success) {
+        setSuccess('API 키가 성공적으로 삭제되었습니다.');
+        setTimeout(() => setSuccess(null), 3000);
+
+        // 사용자 정보 다시 불러오기
+        const res = await externalApiClient.get('/auth/me');
+        if (res.success && res.data) {
+          setUser(res.data);
+        }
+      } else {
+        setError(data.error?.message || 'API 키 삭제에 실패했습니다.');
+      }
+    } catch (error) {
+      console.error('API 키 삭제 오류:', error);
+      setError('API 키 삭제 중 오류가 발생했습니다.');
+    } finally {
+      setDeletingApiKey(false);
+      setShowApiKeyDeleteModal(false);
+      setApiKeyToDelete(null);
+    }
+  };
+
 
   // 중요도에 따른 색상 반환
   const getImportanceColor = (level: number) => {
@@ -584,6 +634,13 @@ export default function ProfilePage() {
                     >
                       복사
                     </button>
+                    <button
+                      onClick={() => handleDeleteApiKey(k)}
+                      className="shrink-0 px-2 py-0.5 text-xs text-white bg-red-600 hover:bg-red-700 rounded transition-colors"
+                      title="API 키 삭제"
+                    >
+                      삭제
+                    </button>
                   </div>
                 ))}
                 {copied && <div className="text-green-600 text-xs">API 키가 복사되었습니다!</div>}
@@ -703,7 +760,7 @@ export default function ProfilePage() {
                     : 'text-gray-500 hover:text-gray-700 dark:text-gray-400 dark:hover:text-gray-300'
                 }`}
               >
-                세션 기록 ({sessionSummaries.length})
+                단기 메모리 ({sessionSummaries.length})
               </button>
             </div>
 
@@ -780,7 +837,7 @@ export default function ProfilePage() {
                           </div>
                         </div>
                         <button
-                          onClick={() => handleDeleteMemory(memory.id || 0)}
+                          onClick={() => handleDeleteMemory(memory)}
                           className="flex-shrink-0 p-1.5 text-gray-400 hover:text-red-500 rounded-full hover:bg-gray-100 dark:hover:bg-gray-700"
                         >
                           <svg className="w-3.5 h-3.5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
@@ -795,7 +852,7 @@ export default function ProfilePage() {
             ) : (
               sessionSummaries.length === 0 ? (
                 <div className="text-center text-xs text-gray-500 py-4">
-                  저장된 세션 기록이 없습니다.
+                  저장된 단기 메모리가 없습니다.
                 </div>
               ) : (
                 <div className="divide-y divide-gray-200/50 dark:divide-gray-700/50">
@@ -914,6 +971,45 @@ export default function ProfilePage() {
         </div>
       )}
 
+      {/* API 키 삭제 확인 모달 */}
+      {showApiKeyDeleteModal && (
+        <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
+          <div className="bg-white dark:bg-gray-800 rounded-lg p-6 max-w-md mx-4">
+            <h3 className="text-lg font-semibold mb-4 text-gray-900 dark:text-gray-100">
+              API 키 삭제 확인
+            </h3>
+            <p className="text-gray-700 dark:text-gray-300 mb-6">
+              {apiKeyToDelete?.name ? (
+                <>
+                  API 키 <strong>{apiKeyToDelete.name}</strong>를 삭제하시겠습니까? 삭제된 API 키는 복구할 수 없으며, 이 키를 사용하는 모든 서비스가 중단됩니다.
+                </>
+              ) : (
+                '이 API 키를 삭제하시겠습니까? 삭제된 API 키는 복구할 수 없습니다.'
+              )}
+            </p>
+            <div className="flex justify-end gap-3">
+              <button
+                onClick={() => {
+                  setShowApiKeyDeleteModal(false);
+                  setApiKeyToDelete(null);
+                }}
+                className="px-4 py-2 text-gray-600 hover:text-gray-800 dark:text-gray-400 dark:hover:text-gray-200"
+                disabled={deletingApiKey}
+              >
+                취소
+              </button>
+              <button
+                onClick={confirmDeleteApiKey}
+                className="px-4 py-2 bg-red-600 text-white rounded hover:bg-red-700 disabled:opacity-50 disabled:cursor-not-allowed"
+                disabled={deletingApiKey}
+              >
+                {deletingApiKey ? '삭제 중...' : '삭제'}
+              </button>
+            </div>
+          </div>
+        </div>
+      )}
+
     </div>
   );
 } 
\ No newline at end of file
