@@ -67,6 +67,11 @@ const configGroups = [
       'USE_ENHANCED_EMBEDDING',
       'ENHANCED_EMBEDDING_STRATEGY',
       'RAG_GENERATE_IMAGE_EMBEDDINGS',
+      'RAG_ENABLE_GRAPHRAG',
+      'RAG_SEARCH_MODE',
+      'RAG_GRAPHRAG_ENTITY_TYPES',
+      'RAG_GRAPHRAG_MAX_GLEANINGS',
+      'RAG_GRAPHRAG_COMMUNITY_DETECTION',
       'RAG_MODE',
       'RAG_CHUNKING_STRATEGY',
       'RAG_PDF_BACKEND',
@@ -183,6 +188,7 @@ const configMeta: Record<string, {
   RAG_LARGE_CONTEXT_CHUNKING: { label: '파일단위 청크', type: 'boolean' },
   USE_ENHANCED_EMBEDDING: { label: '향상된 임베딩 사용', type: 'boolean' },
   ENHANCED_EMBEDDING_STRATEGY: { label: '임베딩 전략', type: 'string' },
+  RAG_GENERATE_IMAGE_EMBEDDINGS: { label: '이미지 임베딩 생성', type: 'boolean' },
   RAG_MODE: { label: '문서처리 모드', type: 'string' },
   RAG_CHUNKING_STRATEGY: { label: '청크 전략', type: 'string' },
   RAG_PDF_BACKEND: { label: 'PDF 백엔드', type: 'string' },
@@ -190,6 +196,12 @@ const configMeta: Record<string, {
   RAG_SEMANTIC_CHUNKER: { label: '시맨틱 청킹', type: 'boolean' },
   RAG_SENTENCE_TRANSFORMER_MODEL: { label: '시맨틱 청킹 모델', type: 'string' },
   RAG_TOP_K: { label: '최종 반환 결과 수', type: 'number' },
+  // GraphRAG 관련 설정
+  RAG_ENABLE_GRAPHRAG: { label: 'Graph RAG 활성화', type: 'boolean' },
+  RAG_SEARCH_MODE: { label: '검색 모드', type: 'string' },
+  RAG_GRAPHRAG_ENTITY_TYPES: { label: '엔티티 타입', type: 'string' },
+  RAG_GRAPHRAG_MAX_GLEANINGS: { label: '최대 정보 수집 횟수', type: 'number' },
+  RAG_GRAPHRAG_COMMUNITY_DETECTION: { label: '커뮤니티 감지', type: 'boolean' },
   SMTP_HOST: { label: 'SMTP Host', type: 'string' },
   SMTP_PASSWORD: { label: 'SMTP 비밀번호', type: 'password' },
   SMTP_PORT: { label: 'SMTP Port', type: 'number' },
@@ -1141,10 +1153,11 @@ export default function SettingsPage() {
     }
     if (group.name === 'rag') {
       // 기존의 quickKeys, processingKeys, chunkingKeys, embeddingKeys는 유지
-      const quickKeys = ['RAG_DOCS_PATH', 'RAG_MODE', 'RAG_CHUNKING_STRATEGY'];
+      const quickKeys = ['RAG_DOCS_PATH', 'RAG_MODE', 'RAG_CHUNKING_STRATEGY', 'RAG_GENERATE_IMAGE_EMBEDDINGS'];
       const processingKeys = ['RAG_FORCE_PDF_CONVERSION', 'RAG_PDF_BACKEND', 'RAG_PROCESS_TEXT_ONLY', 'RAG_DETECT_COLUMN_TYPE'];
       const chunkingKeys = ['RAG_CHUNK_OVERLAP', 'RAG_CHUNK_SIZE', 'RAG_LARGE_CONTEXT_CHUNKING', 'RAG_SEMANTIC_CHUNKER'];
       const embeddingKeys = ['RAG_EMBEDDING_MODEL', 'RAG_SENTENCE_TRANSFORMER_MODEL', 'RAG_IMAGE_EMBEDDING_MODEL', 'USE_ENHANCED_EMBEDDING', 'ENHANCED_EMBEDDING_STRATEGY'];
+      const graphragKeys = ['RAG_ENABLE_GRAPHRAG', 'RAG_SEARCH_MODE', 'RAG_GRAPHRAG_ENTITY_TYPES', 'RAG_GRAPHRAG_MAX_GLEANINGS', 'RAG_GRAPHRAG_COMMUNITY_DETECTION'];
 
       // 가중치 합계 계산 함수
       const calculateWeightSum = (keys: string[]) => {
@@ -1297,6 +1310,22 @@ export default function SettingsPage() {
               })}
             </div>
           </div>
+          {/* GraphRAG */}
+          <div className="rounded-lg p-4 border" style={{ backgroundColor: 'var(--card-bg)', borderColor: 'var(--card-border)' }}>
+            <div className="font-semibold mb-2 text-gray-700 dark:text-gray-200">GraphRAG</div>
+            <div className="space-y-2">
+              {graphragKeys.map((key) => {
+                const meta = configMeta[key];
+                if (!meta) return null;
+                return (
+                  <div key={key} className="flex flex-row items-center justify-between gap-4 border-b border-gray-100 py-2">
+                    <span className="text-base font-medium text-gray-700 dark:text-gray-200 min-w-[180px]">{meta.label}</span>
+                    <div className="flex-1">{renderInput(key, editedConfigs[key], meta)}</div>
+                  </div>
+                );
+              })}
+            </div>
+          </div>
           {/* Retriever */}
           <div className="rounded-lg p-4 border" style={{ backgroundColor: 'var(--card-bg)', borderColor: 'var(--card-border)' }}>
             <div className="font-semibold mb-4 text-gray-700 dark:text-gray-200">Retriever</div>
@@ -1582,7 +1611,7 @@ export default function SettingsPage() {
           );
         }
         if (key === 'RAG_MODE') {
-          const options = ['fast', 'normal', 'rich'];
+          const options = ['fast', 'normal', 'rich', 'intelligence'];
           return (
             <select
               value={value ?? ''}
@@ -1645,6 +1674,25 @@ export default function SettingsPage() {
             </select>
           );
         }
+        if (key === 'RAG_SEARCH_MODE') {
+          const options = ['vector', 'graph', 'hybrid'];
+          return (
+            <select
+              value={value ?? 'vector'}
+              onChange={(e) => handleConfigChange(key, e.target.value)}
+              className="w-full border rounded px-3 py-2 transition"
+              style={{
+                borderColor: 'var(--card-border)',
+                backgroundColor: 'var(--card-bg)',
+                color: 'var(--text-primary)'
+              }}
+            >
+              {options.map(opt => (
+                <option key={opt} value={opt}>{opt}</option>
+              ))}
+            </select>
+          );
+        }
         return (
           <input
             type="text"
