@@ -1,4 +1,4 @@
-import React, { memo, useState } from 'react';
+import React, { memo, useState, useEffect } from 'react';
 import ReactMarkdown from 'react-markdown';
 import remarkGfm from 'remark-gfm';
 import remarkBreaks from 'remark-breaks';
@@ -122,11 +122,32 @@ const ChatCodeBlock = memo(function ChatCodeBlock({ code, language = 'plaintext'
   );
 });
 
-export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({ 
-  content, 
+export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
+  content,
   className = "",
   downloadInfo: propDownloadInfo // 컴포넌트 내부에서 사용할 다운로드 정보 prop
 }) => {
+  // 썸네일 확대 모달 상태
+  const [selectedThumbnail, setSelectedThumbnail] = useState<{image: string, filename: string, page: number} | null>(null);
+
+  // 로드된 썸네일 base64 이미지 캐시 (null = 로드 실패, string = 이미지 데이터)
+  const [thumbnailCache, setThumbnailCache] = useState<Record<string, string | null>>({});
+
+  // 썸네일 표시 설정 상태 (localStorage에서 초기값 로드)
+  const [showThumbnails, setShowThumbnails] = useState<boolean>(() => {
+    if (typeof window !== 'undefined') {
+      const saved = localStorage.getItem('chatShowThumbnails');
+      return saved !== null ? saved === 'true' : true; // 기본값: true (표시)
+    }
+    return true;
+  });
+
+  // 썸네일 설정 변경 시 localStorage에 저장
+  useEffect(() => {
+    if (typeof window !== 'undefined') {
+      localStorage.setItem('chatShowThumbnails', String(showThumbnails));
+    }
+  }, [showThumbnails]);
 
   // 참조 정보 추출 및 content 분리
   const referenceInfoMatch = content.match(/<!-- REFERENCE_INFO:([\s\S]*?) -->/);
@@ -275,6 +296,84 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
 
   // }
 
+  // 썸네일 로드 (downloadInfo가 변경될 때마다)
+  useEffect(() => {
+    if (!downloadInfo || downloadInfo.length === 0) {
+      return;
+    }
+
+    const loadThumbnails = async () => {
+      for (const item of downloadInfo) {
+        if (item.pages && Array.isArray(item.pages)) {
+          for (const pageNum of item.pages) {
+            const cacheKey = `${item.filename}_${pageNum}`;
+
+            // 이미 캐시에 있으면 건너뛰기 (null도 로드 시도 완료를 의미)
+            if (cacheKey in thumbnailCache) {
+              continue;
+            }
+
+            try {
+              // 사용자 ID가 지정된 경우 사용하고, 없으면 여러 가능한 사용자 ID를 시도
+              const possibleUserIds = item.user_id
+                ? [item.user_id]
+                : ['admin', 'shared', 'support'];
+
+              let thumbnailLoaded = false;
+              let lastError: any = null;
+
+              for (const userId of possibleUserIds) {
+                const url = `/api/v1/rag/thumbnail?user_id=${userId}&filename=${encodeURIComponent(item.filename)}&page=${pageNum}`;
+
+                const apiKey = localStorage.getItem('apiKey') || 'airun_1_3d85009c98964579c622eded69997b16';
+                const response = await fetch(url, {
+                  headers: {
+                    'X-API-Key': apiKey
+                  }
+                });
+
+                try {
+                  const data = await response.json();
+
+                  // 성공적으로 이미지를 가져온 경우
+                  if (response.ok && data?.success && data?.data?.image) {
+                    setThumbnailCache(prev => ({
+                      ...prev,
+                      [cacheKey]: data.data.image
+                    }));
+                    thumbnailLoaded = true;
+                    console.log(`[썸네일] 로드 성공 (${item.filename}, 페이지 ${pageNum}, user_id=${userId})`);
+                    break; // 성공했으면 루프 종료
+                  }
+                } catch (parseError) {
+                  lastError = parseError;
+                }
+              }
+
+              // 모든 사용자 ID를 시도했지만 실패한 경우
+              if (!thumbnailLoaded) {
+                console.log(`[썸네일] 모든 사용자 ID 시도 실패 - 숨김 처리 (${item.filename}, 페이지 ${pageNum}):`, lastError);
+                setThumbnailCache(prev => ({
+                  ...prev,
+                  [cacheKey]: null
+                }));
+              }
+            } catch (error) {
+              console.error(`[썸네일] 요청 오류 (${item.filename}, 페이지 ${pageNum}):`, error);
+              // 에러 발생 시에도 null로 표시하여 무한 로딩 방지
+              setThumbnailCache(prev => ({
+                ...prev,
+                [cacheKey]: null
+              }));
+            }
+          }
+        }
+      }
+    };
+
+    loadThumbnails();
+  }, [downloadInfo, thumbnailCache]);
+
   // 출처 섹션이 있는지 확인
   const hasReferencesSection = cleanContent.includes('# 출처(References)') || cleanContent.includes('## 출처')|| cleanContent.includes('출처(References)');
 
@@ -531,13 +630,35 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
       {/* 다운로드 섹션 렌더링 - 웹 링크와 문서 구분 */}
       {downloadInfo.length > 0 && (
         <div className="mt-6 pt-4 border-t border-gray-200 dark:border-gray-700">
-          {/* 출처 제목 추가 */}
-          <h2 className="text-lg font-bold text-gray-900 dark:text-white mb-4 flex items-center space-x-2">
-            <svg className="w-5 h-5 text-blue-600 dark:text-blue-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
-              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12h6m-6 4h6m2 5H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
-            </svg>
-            <span>출처</span>
-          </h2>
+          {/* 출처 제목 및 썸네일 토글 */}
+          <div className="flex items-center justify-between mb-4">
+            <h2 className="text-lg font-bold text-gray-900 dark:text-white flex items-center space-x-2">
+              <svg className="w-5 h-5 text-blue-600 dark:text-blue-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
+                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12h6m-6 4h6m2 5H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
+              </svg>
+              <span>출처</span>
+            </h2>
+            {/* 썸네일 표시 토글 스위치 */}
+            <div className="flex items-center space-x-2">
+              <span className="text-xs text-gray-500 dark:text-gray-400">페이지 미리보기</span>
+              <button
+                type="button"
+                role="switch"
+                aria-checked={showThumbnails}
+                onClick={() => setShowThumbnails(!showThumbnails)}
+                className={`relative inline-flex items-center h-6 w-11 flex-shrink-0 cursor-pointer rounded-full border-2 border-transparent transition-colors duration-200 ease-in-out focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 ${
+                  showThumbnails ? 'bg-blue-600' : 'bg-gray-300 dark:bg-gray-600'
+                }`}
+                title={showThumbnails ? '썸네일 숨기기' : '썸네일 표시'}
+              >
+                <span
+                  className={`pointer-events-none inline-block h-5 w-5 transform rounded-full bg-white shadow ring-0 transition duration-200 ease-in-out ${
+                    showThumbnails ? 'translate-x-5' : 'translate-x-0'
+                  }`}
+                />
+              </button>
+            </div>
+          </div>
           <div className="space-y-1">
             {downloadInfo.map((item, index) => {
               // source 필드로 웹과 문서 구분
@@ -611,66 +732,132 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
                 }
 
                 return (
-                  <div key={index} className="flex items-center justify-between pl-3 p-2 bg-gray-50 dark:bg-gray-800 rounded-lg border border-gray-200 dark:border-gray-600">
-                    <div className="flex items-center space-x-3">
-                      <svg className="w-5 h-5 text-green-600 dark:text-green-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
-                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M7 21h10a2 2 0 002-2V9.414a1 1 0 00-.293-.707l-5.414-5.414A1 1 0 0012.586 3H7a2 2 0 00-2 2v14a2 2 0 002 2z" />
-                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M16 7h-4V3" />
-                      </svg>
-                      <div>
-                        <div className="text-sm font-medium text-gray-900 dark:text-gray-100">
-                          {item.filename}
-                          {item.pages && item.pages.length > 0 && (
-                            <span className="ml-2 text-gray-500 dark:text-gray-400">
-                              (페이지: {item.pages.join(', ')})
-                            </span>
-                          )}
+                  <div key={index} className="flex flex-col pl-3 p-2 bg-gray-50 dark:bg-gray-800 rounded-lg border border-gray-200 dark:border-gray-600">
+                    <div className="flex items-center justify-between">
+                      <div className="flex items-center space-x-3">
+                        <svg className="w-5 h-5 text-green-600 dark:text-green-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
+                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M7 21h10a2 2 0 002-2V9.414a1 1 0 00-.293-.707l-5.414-5.414A1 1 0 0012.586 3H7a2 2 0 00-2 2v14a2 2 0 002 2z" />
+                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M16 7h-4V3" />
+                        </svg>
+                        <div>
+                          <div className="text-sm font-medium text-gray-900 dark:text-gray-100">
+                            {item.filename}
+                            {item.pages && item.pages.length > 0 && (
+                              <span className="ml-2 text-gray-500 dark:text-gray-400">
+                                (페이지: {item.pages.join(', ')})
+                              </span>
+                            )}
+                          </div>
                         </div>
                       </div>
-                    </div>
-                    <button
-                    onClick={async () => {
-                      try {
-                        console.log('[다운로드] 시작:', item.filename);
-                        
-                        const response = await fetch(downloadUrl, {
-                          method: 'GET',
-                          headers: {
-                            'X-API-Key': localStorage.getItem('apiKey') || 'airun_1_3d85009c98964579c622eded69997b16',
-                            'Authorization': `Bearer ${localStorage.getItem('userToken') || ''}`
+                      <button
+                        onClick={async () => {
+                          try {
+                            console.log('[다운로드] 시작:', item.filename);
+
+                            const response = await fetch(downloadUrl, {
+                              method: 'GET',
+                              headers: {
+                                'X-API-Key': localStorage.getItem('apiKey') || 'airun_1_3d85009c98964579c622eded69997b16',
+                                'Authorization': `Bearer ${localStorage.getItem('userToken') || ''}`
+                              }
+                            });
+
+                            if (!response.ok) {
+                              const errorData = await response.json().catch(() => ({ error: { message: '파일을 찾을 수 없습니다.' } }));
+                              throw new Error(errorData.error?.message || '파일을 찾을 수 없습니다.');
+                            }
+
+                            const blob = await response.blob();
+                            const url = window.URL.createObjectURL(blob);
+                            const a = document.createElement('a');
+                            a.href = url;
+                            a.download = item.filename;
+                            document.body.appendChild(a);
+                            a.click();
+                            window.URL.revokeObjectURL(url);
+                            document.body.removeChild(a);
+
+                            console.log('[다운로드] 완료:', item.filename);
+                          } catch (error) {
+                            console.error('다운로드 오류:', error);
+                            alert('다운로드에 실패했습니다: ' + (error instanceof Error ? error.message : String(error)));
                           }
-                        });
-                        
-                        if (!response.ok) {
-                          const errorData = await response.json().catch(() => ({ error: { message: '파일을 찾을 수 없습니다.' } }));
-                          throw new Error(errorData.error?.message || '파일을 찾을 수 없습니다.');
-                        }
-                        
-                        const blob = await response.blob();
-                        const url = window.URL.createObjectURL(blob);
-                        const a = document.createElement('a');
-                        a.href = url;
-                        a.download = item.filename;
-                        document.body.appendChild(a);
-                        a.click();
-                        window.URL.revokeObjectURL(url);
-                        document.body.removeChild(a);
-                        
-                        console.log('[다운로드] 완료:', item.filename);
-                      } catch (error) {
-                        console.error('다운로드 오류:', error);
-                        alert('다운로드에 실패했습니다: ' + (error instanceof Error ? error.message : String(error)));
-                      }
-                    }}
-                    className="inline-flex items-center px-3 py-1.5 text-xs font-medium text-white bg-blue-600 hover:bg-blue-700 rounded-md transition-colors duration-200"
-                    title={`${item.filename} 다운로드`}
-                  >
-                    <svg className="w-3 h-3 mr-1" fill="none" stroke="currentColor" viewBox="0 0 24 24">
-                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
-                    </svg>
-                    다운로드
-                  </button>
-                </div>
+                        }}
+                        className="inline-flex items-center px-3 py-1.5 text-xs font-medium text-white bg-blue-600 hover:bg-blue-700 rounded-md transition-colors duration-200"
+                        title={`${item.filename} 다운로드`}
+                      >
+                        <svg className="w-3 h-3 mr-1" fill="none" stroke="currentColor" viewBox="0 0 24 24">
+                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 10v6m0 0l-3-3m3 3l3-3m2 8H7a2 2 0 01-2-2V5a2 2 0 012-2h5.586a1 1 0 01.707.293l5.414 5.414a1 1 0 01.293.707V19a2 2 0 01-2 2z" />
+                        </svg>
+                        다운로드
+                      </button>
+                    </div>
+
+                    {/* 페이지 썸네일 미리보기 - 다운로드 버튼 아래 별도 영역 (토글 설정에 따라 표시) */}
+                    {showThumbnails && item.pages && item.pages.length > 0 && (() => {
+                      // 유효한 썸네일이 있는 페이지만 필터링
+                      const validPages = item.pages.filter((pageNum: number) => {
+                        const cacheKey = `${item.filename}_${pageNum}`;
+                        // 캐시에 키가 없거나(로딩 중) 값이 문자열(이미지 있음)인 경우만 포함
+                        // null인 경우(로드 실패)는 제외
+                        return !(cacheKey in thumbnailCache && thumbnailCache[cacheKey] === null);
+                      });
+
+                      // 유효한 페이지가 없으면 썸네일 섹션 자체를 표시하지 않음
+                      if (validPages.length === 0) return null;
+
+                      return (
+                        <div className="mt-3 pt-3 border-t border-gray-200 dark:border-gray-600">
+                          <div className="flex flex-col gap-3">
+                            {validPages.map((pageNum: number) => {
+                              const cacheKey = `${item.filename}_${pageNum}`;
+                              const thumbnailImage = thumbnailCache[cacheKey];
+
+                              return (
+                                <div key={pageNum} className="relative group">
+                                  {thumbnailImage ? (
+                                    <div
+                                      className="relative cursor-pointer overflow-hidden rounded-lg border border-gray-300 dark:border-gray-600 hover:border-blue-500 dark:hover:border-blue-400 transition-all duration-200 hover:shadow-lg"
+                                      onClick={() => setSelectedThumbnail({
+                                        image: thumbnailImage,
+                                        filename: item.filename,
+                                        page: pageNum
+                                      })}
+                                    >
+                                      <div className="absolute top-2 left-2 z-10 bg-blue-600 text-white text-xs font-medium px-2 py-1 rounded shadow-md">
+                                        p.{pageNum}
+                                      </div>
+                                      <img
+                                        src={thumbnailImage}
+                                        alt={`${item.filename} - 페이지 ${pageNum}`}
+                                        className="max-w-[800px] w-auto h-auto object-contain bg-white dark:bg-gray-900"
+                                      />
+                                      <div className="absolute inset-0 bg-black bg-opacity-0 group-hover:bg-opacity-10 transition-all duration-200 flex items-center justify-center">
+                                        <svg
+                                          className="w-8 h-8 text-white opacity-0 group-hover:opacity-100 transition-opacity duration-200"
+                                          fill="none"
+                                          stroke="currentColor"
+                                          viewBox="0 0 24 24"
+                                        >
+                                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M21 21l-6-6m2-5a7 7 0 11-14 0 7 7 0 0114 0zM10 7v3m0 0v3m0-3h3m-3 0H7" />
+                                        </svg>
+                                      </div>
+                                    </div>
+                                  ) : (
+                                    <div className="max-w-[800px] w-auto h-64 bg-gray-100 dark:bg-gray-700 rounded-lg border border-gray-300 dark:border-gray-600 flex flex-col items-center justify-center">
+                                      <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-blue-600 mb-2"></div>
+                                      <span className="text-sm text-gray-500 dark:text-gray-400">페이지 {pageNum} 로딩 중...</span>
+                                    </div>
+                                  )}
+                                </div>
+                              );
+                            })}
+                          </div>
+                        </div>
+                      );
+                    })()}
+                  </div>
               );
               }
             })}
@@ -678,6 +865,69 @@ export const ChatMarkdownRenderer: React.FC<ChatMarkdownRendererProps> = ({
         </div>
       )}
 
+      {/* 썸네일 확대 모달 */}
+      {selectedThumbnail && (
+        <div
+          className="fixed inset-0 z-50 flex items-center justify-center bg-black bg-opacity-75 p-4"
+          onClick={() => setSelectedThumbnail(null)}
+          onKeyDown={(e) => {
+            if (e.key === 'Escape') {
+              setSelectedThumbnail(null);
+            }
+          }}
+          tabIndex={0}
+        >
+          <div
+            className="relative max-w-7xl w-full max-h-[95vh] bg-white dark:bg-gray-800 rounded-lg shadow-2xl overflow-hidden"
+            onClick={(e) => e.stopPropagation()}
+          >
+            {/* 모달 헤더 */}
+            <div className="flex items-center justify-between px-4 py-3 bg-gray-100 dark:bg-gray-700 border-b border-gray-200 dark:border-gray-600">
+              <div className="flex items-center space-x-3">
+                <svg className="w-5 h-5 text-blue-600 dark:text-blue-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
+                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M7 21h10a2 2 0 002-2V9.414a1 1 0 00-.293-.707l-5.414-5.414A1 1 0 0012.586 3H7a2 2 0 00-2 2v14a2 2 0 002 2z" />
+                </svg>
+                <div>
+                  <h3 className="text-sm font-semibold text-gray-900 dark:text-gray-100">
+                    {selectedThumbnail.filename}
+                  </h3>
+                  <p className="text-xs text-gray-500 dark:text-gray-400">
+                    페이지 {selectedThumbnail.page}
+                  </p>
+                </div>
+              </div>
+              <button
+                onClick={() => setSelectedThumbnail(null)}
+                className="p-1 hover:bg-gray-200 dark:hover:bg-gray-600 rounded-full transition-colors"
+                aria-label="닫기"
+              >
+                <svg className="w-5 h-5 text-gray-600 dark:text-gray-300" fill="none" stroke="currentColor" viewBox="0 0 24 24">
+                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
+                </svg>
+              </button>
+            </div>
+
+            {/* 모달 본문 - 썸네일 이미지 */}
+            <div className="flex items-center justify-center p-6 bg-gray-50 dark:bg-gray-900">
+              <img
+                src={selectedThumbnail.image}
+                alt={`${selectedThumbnail.filename} - 페이지 ${selectedThumbnail.page}`}
+                className="max-w-full max-h-[85vh] object-contain rounded shadow-lg"
+              />
+            </div>
+
+            {/* 모달 푸터 */}
+            <div className="px-4 py-3 bg-gray-100 dark:bg-gray-700 border-t border-gray-200 dark:border-gray-600 flex justify-end">
+              <button
+                onClick={() => setSelectedThumbnail(null)}
+                className="px-4 py-2 text-sm font-medium text-gray-700 dark:text-gray-200 bg-white dark:bg-gray-600 hover:bg-gray-100 dark:hover:bg-gray-500 rounded-md border border-gray-300 dark:border-gray-500 transition-colors"
+              >
+                닫기
+              </button>
+            </div>
+          </div>
+        </div>
+      )}
 
     </div>
   );
