@@ -5,7 +5,7 @@ import Header from '@/components/Header';
 
 export default function ConditionalLayout({ children }: { children: React.ReactNode }) {
   const pathname = usePathname();
-  const isFormPage = pathname?.startsWith('/form/');
+  const isFormPage = pathname?.startsWith('/form/') || pathname?.startsWith('/formbuilder/form/');
 
   if (isFormPage) {
     // 폼 페이지: 헤더 없이 전체 화면 사용
