@@ -15,7 +15,6 @@ import {
   HelpCircle,
   FolderOpen,
   Brain,
-  Cpu,
   TrendingUp,
   Users,
   Settings,
@@ -25,8 +24,7 @@ import {
   Menu,
   ChevronDown,
   Building2,
-  Activity,
-  Files,
+  Wrench,
   FormInput
 } from 'lucide-react';
 
@@ -46,6 +44,7 @@ const getMenuVisibility = () => {
     agent: process.env.NEXT_PUBLIC_ENABLE_AGENT === 'true',
     assistant: process.env.NEXT_PUBLIC_ENABLE_ASSISTANT === 'true',
     document: process.env.NEXT_PUBLIC_ENABLE_DOCUMENT === 'true',
+    quotation: process.env.NEXT_PUBLIC_ENABLE_QUOTATION === 'true',
     flowai: process.env.NEXT_PUBLIC_ENABLE_FLOWAI === 'true',
     business: process.env.NEXT_PUBLIC_ENABLE_BUSINESS === 'true',
     formbuilder: process.env.NEXT_PUBLIC_ENABLE_FORMBUILDER === 'true',
@@ -90,10 +89,11 @@ export default function Header() {
   const userNavigationItems = [
     { name: t('header.chat', '대화하기'), path: '/chat', icon: MessageSquare, section: 'chat', enabled: menuVisibility.chat },
     { name: t('header.code', '코드'), path: '/code', icon: Code, section: 'code', enabled: menuVisibility.code },
-    { name: t('header.agent', '자동화'), path: '/agent', icon: Bot, section: 'agent', enabled: menuVisibility.agent },
+    { name: t('header.agent', '에이전트'), path: '/agent', icon: Bot, section: 'agent', enabled: menuVisibility.agent },
+    { name: t('header.formbuilder', '폼빌더'), path: '/formbuilder', icon: FormInput, section: 'formbuilder', enabled: menuVisibility.formbuilder },
+    { name: t('header.tools', '도구'), path: '/tools', icon: Wrench, section: 'tools', enabled: menuVisibility.quotation },
     { name: t('header.assistant', 'Assistant'), path: '/assistant', icon: User, section: 'assistant', enabled: menuVisibility.assistant },
     { name: t('header.document', '문서'), path: '/document', icon: FileText, section: 'document', enabled: menuVisibility.document },
-    { name: t('header.formbuilder', '폼빌더'), path: '/formbuilder', icon: FormInput, section: 'formbuilder', enabled: menuVisibility.formbuilder },
     { name: t('header.business', '사업분석'), path: '/business', icon: Building2, section: 'business', enabled: menuVisibility.business },
     { name: t('header.support', '고객센터'), path: '/support', icon: HelpCircle, section: 'support', enabled: menuVisibility.support }
   ].filter(item => item.enabled);
@@ -106,8 +106,6 @@ export default function Header() {
   // 관리자용 추가 메뉴 (환경 변수 기반 필터링)
   const adminNavigationItems = [
     { name: t('header.rag', 'RAG'), path: '/admin/rag', icon: FolderOpen, section: 'rag', enabled: menuVisibility.ragAdmin },
-    { name: t('header.health', '헬스'), path: '/admin/health-batch', icon: Activity, section: 'health-batch', enabled: true },
-    { name: t('header.esg', 'ESG'), path: '/admin/esg-analysis', icon: Files, section: 'esg-analysis', enabled: true },
     { name: t('header.models', '파인튜닝'), path: '/admin/models', icon: Brain, section: 'models', enabled: menuVisibility.modelAdmin },
     { name: t('header.evaluation', '평가'), path: '/admin/evaluation', icon: TrendingUp, section: 'evaluation', enabled: menuVisibility.evaluation },
     { name: t('header.users', '사용자'), path: '/admin/users', icon: Users, section: 'users', enabled: menuVisibility.userAdmin },
