@@ -114,7 +114,7 @@ export function getServerConfig(): ServerConfig {
       host: process.env.DB_HOST || 'localhost',
       port: parseInt(process.env.DB_PORT || '5433'),
       user: process.env.DB_USER || 'ivs',
-      password: process.env.DB_PASSWORD || '1234',
+      password: process.env.DB_PASSWORD || "Exitem08**",
       name: process.env.DB_NAME || 'airun'
     },
     
@@ -169,7 +169,7 @@ async function fetchDatabaseConfigFromAPI(): Promise<ServerConfig['database']> {
       host: config.DB_HOST || 'localhost',
       port: parseInt(config.DB_PORT || '5433'),
       user: config.DB_USER || 'ivs',
-      password: config.DB_PASSWORD || '1234',
+      password: config.DB_PASSWORD || "Exitem08**",
       name: config.DB_NAME || 'airun',
     };
 
@@ -183,7 +183,7 @@ async function fetchDatabaseConfigFromAPI(): Promise<ServerConfig['database']> {
       host: process.env.DB_HOST || 'localhost',
       port: parseInt(process.env.DB_PORT || '5433'),
       user: process.env.DB_USER || 'ivs',
-      password: process.env.DB_PASSWORD || '1234',
+      password: process.env.DB_PASSWORD || "Exitem08**",
       name: process.env.DB_NAME || 'airun',
     };
 
