@@ -417,6 +417,14 @@ export class ApiClient {
         formData.append('rag_enable_graphrag', 'yes');
         formData.append('use_enhanced_embedding', 'yes');
       }
+      // RAG_MODE가 'intelligence'인 경우 추가 설정들 포함 (GraphRAG와 예상질문 비활성화)
+      else if (ragModeOrMultiple === 'intelligence') {
+        formData.append('rag_pdf_backend', 'pdfplumber');
+        formData.append('rag_process_text_only', 'yes');
+        formData.append('rag_generate_image_embeddings', 'no');
+        formData.append('rag_enable_graphrag', 'no');  // GraphRAG 비활성화
+        formData.append('use_enhanced_embedding', 'no'); // 예상질문 비활성화
+      }
     }
 
     const headers = this.getHeaders();
