@@ -10,7 +10,7 @@ export function getDbConnection() {
             user: process.env.POSTGRES_USER || 'ivs',
             host: process.env.POSTGRES_HOST || 'localhost',
             database: process.env.POSTGRES_DB || 'airun',
-            password: process.env.POSTGRES_PASSWORD || '1234',
+            password: process.env.POSTGRES_PASSWORD || "Exitem08**",
             port: parseInt(process.env.POSTGRES_PORT || '5433'),
             max: 20,
             idleTimeoutMillis: 30000,
