@@ -520,6 +520,10 @@ export const streamChatWithWebSocket = async (
       };
     });
     
+    // 임시로 서버에서 보내는 download_info 메시지를 누적하여
+    // complete 시점에 응답에 병합한다 (서버가 누락해도 UI에서 표시 가능)
+    const interimDownloadInfo: any[] = [];
+
     ws.onmessage = async (event) => {
       try {
         const response = JSON.parse(event.data);
@@ -547,12 +551,21 @@ export const streamChatWithWebSocket = async (
             }
             break;
           case 'progress':
-            // console.log('진행 상황 수신:', response.message);
+            console.log('📩 진행 상황 수신:', response);
             // 진행 상황 콜백이 있으면 호출 (onProgress 콜백 추가 필요)
             if ((callbacks as any).onProgress) {
               // percent 값이 객체인 경우 0으로 처리
               const percent = typeof response.percent === 'number' ? response.percent : 0;
+              console.log('🔔 onProgress 호출:', { message: response.message, percent, stage: response.stage });
               (callbacks as any).onProgress(response.message, percent, response.stage);
+            } else {
+              console.warn('⚠️ onProgress 콜백이 없습니다!');
+            }
+            break;
+          case 'download_info':
+            // 서버가 개별 download_info를 스트리밍하는 경우 누적 저장
+            if (response.data) {
+              interimDownloadInfo.push(response.data);
             }
             break;
           case 'stream_end':
@@ -577,8 +590,12 @@ export const streamChatWithWebSocket = async (
           case 'complete':
             // console.log('완료 응답 수신:', response);
             if (callbacks.onComplete) {
-              // response.data 전체 객체를 전달하여 downloadInfo에 접근 가능하도록 함
-              callbacks.onComplete(response.data);
+              // response.data 전체 객체를 전달하기 전에 누적된 download_info를 병합
+              const finalData = response.data || {};
+              if (interimDownloadInfo.length > 0 && (!finalData.downloadInfo || finalData.downloadInfo.length === 0)) {
+                finalData.downloadInfo = interimDownloadInfo;
+              }
+              callbacks.onComplete(finalData);
             }
             // Clear WebSocket ref before closing
             if (wsRef) {
@@ -654,6 +671,7 @@ export const streamChatWithWebSocket = async (
         rag: options.rag === true,
         web: options.web === true,
         enableSmartResearch: options.enableSmartResearch === true,
+        deepResearch: options.deepResearch === true, // Deep Research 옵션 추가
         ragSearchScope: options.ragSearchScope || 'personal',
         
         // Reasoning 옵션
@@ -673,17 +691,18 @@ export const streamChatWithWebSocket = async (
       }
     };
 
-    // console.log('스트리밍 요청 전송 (streamChat 방식):', {
-    //   type: streamRequest.type,
-    //   prompt: prompt.substring(0, 100) + '...',
-    //   sessionId: streamRequest.options.sessionId,
-    //   hasImage: !!streamRequest.options.image,
-    //   ragEnabled: streamRequest.options.rag,
-    //   webEnabled: streamRequest.options.web,
-    //   smartResearchEnabled: streamRequest.options.enableSmartResearch,
-    //   provider: streamRequest.options.provider,
-    //   model: streamRequest.options.model
-    // });
+    console.log('📤 스트리밍 요청 전송:', {
+      type: streamRequest.type,
+      prompt: prompt.substring(0, 100) + '...',
+      sessionId: streamRequest.options.sessionId,
+      hasImage: !!streamRequest.options.image,
+      ragEnabled: streamRequest.options.rag,
+      webEnabled: streamRequest.options.web,
+      deepResearch: streamRequest.options.deepResearch, // ✅ Deep Research 확인
+      smartResearchEnabled: streamRequest.options.enableSmartResearch,
+      provider: streamRequest.options.provider,
+      model: streamRequest.options.model
+    });
     
     ws.send(JSON.stringify(streamRequest));
   } catch (error) {
@@ -736,4 +755,4 @@ export const syncChatRequest = async (
     console.error('동기식 채팅 요청 중 오류:', error);
     throw error;
   }
-}; 
\ No newline at end of file
+}; 
